@@ -104,8 +104,14 @@ class AttachToPatchesOp(hook.DataOperationMixIn, hook.LateOperation):
 
     def create_patch(self, rev):
         name = rev.description.splitlines()[0]
-        return self.session.create_entity('Patch', patch_name=name,
-                                           patch_revision=[rev])
+        kwargs = {'patch_name': name, 'patch_revision': rev}
+        users = users_by_author(self.session.execute, rev.author)
+        if users:
+            kwargs['created_by'] = users[0]
+        patch = self.session.create_entity('Patch', **kwargs)
+        msg = '%s: New patch %i for new draft revision %s'
+        self.info(msg, rev.repository.dc_title(), patch.eid, rev.changeset)
+        return patch
 
 class PatchLifeCheckOp(hook.DataOperationMixIn, hook.SingleLastOperation):
     """Put patches in the right state
