@@ -32,7 +32,8 @@ from cubicweb.schema import (WorkflowableEntityType,
 from cubes.vcsfile.schema import Repository
 
 
-Repository.add_relation(Boolean(default=False), name='has_review')
+Repository.add_relation(Boolean(default=False, required=True),
+                        name='has_review')
 
 # the patch entity #############################################################
 
@@ -91,9 +92,9 @@ class patch_reviewer(RelationDefinition):
     __permissions__ = {
         'read': ('managers', 'users', 'guests'),
         'add': ('managers', 'committers',
-                RRQLExpression('S repository_committer U')),
+                RRQLExpression('S patch_revision RE, RE from_repository R, R repository_committer U')),
         'delete': ('managers', 'committers',
-                   RRQLExpression('S repository_committer U')),
+                   RRQLExpression('S patch_revision RE, RE from_repository R, R repository_committer U')),
         }
     subject = 'Patch'
     object = 'CWUser'
@@ -107,9 +108,9 @@ class patch_committer(RelationDefinition):
     __permissions__ = {
         'read': ('managers', 'users', 'guests'),
         'add': ('managers', 'committers',
-                RRQLExpression('S repository_committer U')),
+                RRQLExpression('S patch_revision RE, RE from_repository R, R repository_committer U')),
         'delete': ('managers', 'committers',
-                   RRQLExpression('S repository_committer U')),
+                   RRQLExpression('S patch_revision RE, RE from_repository R, R repository_committer U')),
         }
     subject = 'Patch'
     object = 'CWUser'
