@@ -529,6 +529,8 @@ class PatchNotificationTC(CubicWebTC):
                                '            R author ILIKE "Victor%"')
         victor_patch = set(eid for eid, in rset)
         self.assertTrue(victor_patch.issubset(all_nosy))
+        patch = rset.get_entity(0, 0)
+        self.assertEqual(victor.eid, patch.creator.eid)
 
     def test_reviewer_email(self):
         session = self.session
