@@ -16,43 +16,80 @@
 
 from __future__ import with_statement
 
+import os.path as osp
+import functools
+import tempfile
+import tarfile
+from shutil import rmtree
+
+from logilab.common.decorators import classproperty
+
 from cubicweb.devtools.testlib import CubicWebTC
 from cubicweb.server.session import security_enabled, hooks_control
 
+from cubes.vcsfile.testutils import init_vcsrepo
+
 class PatchReviewWorkflowTC(CubicWebTC):
 
+    @classmethod
+    def setUpClass(cls):
+        cls.__tmpdir = tempfile.mkdtemp(prefix='vcreview-test-')
+        tarfile.open(cls.repo_path + '.tar').extractall(cls.__tmpdir)
+
+    @classmethod
+    def tearDownClass(cls):
+        cls.cleanup()
+
+    @classmethod
+    def cleanup(cls):
+        try:
+            rmtree(cls.__tmpdir)
+        except:
+            pass
+
+    @classproperty
+    def full_repo_path(cls):
+        return osp.join(cls.__tmpdir, u'repo')
+
     def setup_database(self):
-        req = self.request()
-        self.reviewer1 = self.create_user(req, 'reviewer1', ('users', 'reviewers'),
-                                          email=u'reviewer1@cwo')
-        self.reviewer2 = self.create_user(req, 'reviewer2', ('users', 'reviewers'),
-                                          email=u'reviewer2@cwo')
-        self.committer = self.create_user(req, 'committer', ('users',))
         session = self.session
         session.set_cnxset()
+        create_user = functools.partial(self.create_user, session)
+        self.reviewer1 = create_user('Victor', ('users', 'reviewers'),
+                                     email=u'victor@ratax.es')
+        session.set_cnxset()
+        self.reviewer2 = create_user('Podular', ('users', 'reviewers'),
+                                     email=u'podular@elephan.tz')
+        session.set_cnxset()
+        self.committer = create_user('committer', ('users',))
+        session.set_cnxset()
         with security_enabled(session, write=False):
             with hooks_control(session, session.HOOKS_DENY_ALL, 'metadata'):
-                vcrepo = session.create_entity(
-                    'Repository', repository_committer=self.committer)
-                self.patch1eid = session.create_entity(
-                    'Patch', patch_repository=vcrepo, originator=u'bob <reviewer1@cwo>').eid
-                self.patch2eid = session.create_entity(
-                    'Patch', patch_repository=vcrepo, originator=u'bob <reviewer1@cwo>').eid
+                session.create_entity('Repository',
+                                      type=u'mercurial',
+                                      encoding=u'utf8',
+                                      path=self.full_repo_path,
+                                      repository_committer=self.committer,
+                                      has_review=True)
+                self.commit()
+                session.set_cnxset()
+                init_vcsrepo(self.repo)
+                rset = session.execute('Patch P ORDERBY P DESC '
+                                       'WHERE P in_state S, '
+                                       '      S name "pending-review"')
+                self.patch1eid = rset[1][0]
+                self.patch2eid = rset[2][0]
                 session.commit(free_cnxset=False)
                 self.task1eid = session.create_entity(
                     'Task', reverse_has_activity=self.patch1eid, title=u'todo 1').eid
+        self.session.commit(free_cnxset=False)
 
     def test_wf(self):
         req = self.request()
         patch = req.execute('Any X WHERE X eid %(x)s', {'x': self.patch1eid}).get_entity(0, 0)
-        self.assertFalse(patch.patch_reviewer)
-        self.assertTrue(self.reviewer1.eid in [u.eid for u in patch.created_by])
-        self.assertTrue(self.reviewer1.eid in [u.eid for u in patch.owned_by])
-        patch.cw_adapt_to('IWorkflowable').fire_transition('ask review')
-        self.commit()
         patch.cw_clear_all_caches()
         self.assertEqual(patch.patch_reviewer[0].eid, self.reviewer2.eid)
-        with self.login('reviewer1'):
+        with self.login('Victor'):
             req = self.request()
             rset = req.execute('Any X WHERE X eid %(x)s', {'x': self.patch1eid})
             self.assertListEqual(sorted(x[0] for x in self.action_submenu(req, rset, 'workflow')),
@@ -61,9 +98,6 @@ class PatchReviewWorkflowTC(CubicWebTC):
             # already has a patch for review, it should be picked anyway as a
             # patch creator can't be its reviewer
             patch = req.execute('Any X WHERE X eid %(x)s', {'x': self.patch2eid}).get_entity(0, 0)
-            self.assertFalse(patch.patch_reviewer)
-            patch.cw_adapt_to('IWorkflowable').fire_transition('ask review')
-            self.commit()
             patch.cw_clear_all_caches()
             self.assertEqual(patch.patch_reviewer[0].eid, self.reviewer2.eid)
             # create a task and mark the task1 as done
@@ -72,7 +106,7 @@ class PatchReviewWorkflowTC(CubicWebTC):
             task = req.execute('Any X WHERE X eid %(x)s', {'x': self.task1eid}).get_entity(0, 0)
             task.cw_adapt_to('IWorkflowable').fire_transition('done')
             self.commit()
-        with self.login('reviewer2'):
+        with self.login('Podular'):
             req = self.request()
             rset = req.execute('Any X WHERE X eid %(x)s', {'x': self.patch1eid})
             self.assertListEqual(sorted(x[0] for x in self.action_submenu(req, rset, 'workflow')),
@@ -105,6 +139,9 @@ class PatchReviewWorkflowTC(CubicWebTC):
             task.cw_adapt_to('IWorkflowable').fire_transition('done')
             self.commit()
 
+PatchReviewWorkflowTC.repo_path = osp.join(PatchReviewWorkflowTC.datadir,
+                                      u'demo-repo-final')
+
 
 
 if __name__ == '__main__':
